/*
 * Copyright (C) 2009 SHARP Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.co.sharp.android.SampleConfigChange;

import android.app.Activity;
import android.content.res.Configuration;
import android.os.Bundle;
/* ***** 実機で実行する場合、このコードを使用すること ****** *
import android.os.Vibrator;
* */
import android.widget.TextView;

/**
 * 端末の状態変化通知を取得するサンプルである。
 * 実機ではクラムシェルの開閉が起きた時に、コールバック通知を取得し、
 * 開いた回数・閉じた回数をカウントする。
 * エミュレーターでは画面回転が起きた時に、コールバック通知を取得し、
 * 回転するたびに回数をカウントする。
 *
 * AndroidManifest.xmlに登録した端末状態変化の通知を受けるために
 * onConfigurationChangedを実装する。
 *
 * Manifestファイルへの記述および、状態変化通知が起きる値がエミュレータと実機で
 * 異なるため、ソースコードも異なっている点に注意が必要である。
 */
public class SampleConfigChangeActivity extends Activity {

    /** 開けた回数 */
    private int mOpen;
    /** 閉じた回数 */
    private int mClose;

    /**
     *  アクティビティ作成時に呼ばれるメソッドである。
     *  初期表示と回数カウンタの初期化を行う。
     */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        setTitle(R.string.sample_configchange_name);

        /* 初期表示を設定 */
        TextView configChangeTextView = (TextView) this.findViewById(R.id.config_change_info);
        configChangeTextView.setText(R.string.sample_configchange_name);
        /* 回数カウンタの初期化 */
        mOpen = 0;
        mClose = 0;
    }

    /**
     * 端末状態が変化したときに呼ばれるメソッドである。
     * AndroidManifest.xmlに登録した端末状態の変化が起こったときに本メソッドが呼ばれる。
     * 変化後のコンフィギュレーションは、引数に格納されている。
     * 実機の場合、「keyboardHidden」のみの登録でよいが、エミュレータの場合「orientation」も
     * 登録しないと、クラムシェルを閉じたことが通知されないので、注意が必要である。
     * @param newConfiguration 新しい端末状態
     */
    @Override
    public void onConfigurationChanged(Configuration newConfiguration) {
        super.onConfigurationChanged(newConfiguration);
        TextView configChangeTextView = (TextView) this.findViewById(R.id.config_change_info);

       /* ***** 実機で実行する場合は、こちらのコードを使用すること。 *****
        if (Configuration.HARDKEYBOARDHIDDEN_YES == newConfiguration.hardKeyboardHidden) {
            // 閉じた
            mClose++;
            // android.os.Vibratorをインポートすること
            // バイブレーションの設定を行う
            Vibrator vibrator = (Vibrator) getSystemService(VIBRATOR_SERVICE);
            final long[] pattern = {0,1000,500,300,100,50};
            // 振動させる
            vibrator.vibrate(pattern, -1);
        } else if (Configuration.HARDKEYBOARDHIDDEN_NO == newConfiguration.hardKeyboardHidden) {
            // 開いた
            mOpen++;
            // 回数を画面に表示する
            String message = getResources().getString(R.string.sample_configchange_open) + "!\n";
            message += getResources().getString(R.string.sample_configchange_open) + mOpen + "\n" +
            getResources().getString(R.string.sample_configchange_close) + mClose;
            configChangeTextView.setText(message);
        }

        * *************************************************************************** */

        /* *** エミュレータで実行する場合は、こちらのコードを使用すること。 ****/

        if (Configuration.HARDKEYBOARDHIDDEN_NO == newConfiguration.hardKeyboardHidden &&
                Configuration.ORIENTATION_LANDSCAPE == newConfiguration.orientation) {
            // 開いた（初期位置に戻った場合）
            mOpen++;
        } else {
            // 閉じた（初期位置から回転した場合）
            mClose++;
        }
        // 回数を画面に表示する
        String message = getResources().getString(R.string.sample_configchange_orientation) + "\n" +
        getResources().getString(R.string.sample_configchange_open) + mOpen + "\n" +
        getResources().getString(R.string.sample_configchange_close) + mClose;
        configChangeTextView.setText(message);

        /* ************************************************************************** */

    }
}